// You can import API functions like this from D3.js.
import {
  select,
  max,
  csv,
  scaleBand,
  scaleLinear,
  axisLeft,
  axisBottom,
} from 'd3';

const svg = select('svg');

var data;

const width = +svg.attr('width');
const height = +svg.attr('height');
var margin = {
  left: 80,
  top: 10,
  bottom: 100,
  right: 10,
};

const x = scaleBand().range([
  margin.left,
  width - margin.right - margin.right,
]);
var xAx = svg
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',0)'
  );

const y = scaleLinear().range([
  height - margin.bottom,
  margin.top,
]);
var yAx = svg
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',0)'
  );

const update = (data) => {
  x.domain(data.map((d) => d.Country));
  xAx
    .call(d3.axisBottom(x))
    .attr('transform', 'translate(0, 410)')
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('dx', '-1em')
    .attr('dy', '-0.5em')
    .attr('transform', 'rotate(-60)');

  y.domain([
    0,
    max(data, (d) => +d['2022 Population']),
  ]);
  yAx.call(d3.axisLeft(y));

  svg
    .selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('x', (d) => x(d.Country))
    .attr('y', (d) => y(+d['2022 Population']))
    .attr('width', x.bandwidth())
    .attr(
      'height',
      (d) =>
        height -
        margin.bottom -
        y(d['2022 Population'])
    )
  .on('mouseover', function(d) {
    var x = d3.event.pageX;
    var y = d3.event.pageY;
   d3.select('div.tooltip')
    .style('left', x + 'px')
    .style('top', y + 'px')
        .html(
          'Country: ' +
            d.Country +
            '<br>' +
            'Population: ' +
            d['2022 Population']
        );
    });
  
}
csv('data.csv').then((d) => {
  data = d
  update(data);
});




d3.selectAll(".button_click").on("click", function () {
  if(d3.select(this).attr("id") == "asc")
  {
    data = data.sort(function(a, b) {
      return d3['descending'](+a['2022 Population'], 
                              +b['2022 Population'])});
    update(data);
  }
})


// export function sayHello() {
// 	console.log("HW");
// }

//       data = data.sort(function(a, b) {
//             return d3['descending'](+a['2022 Population'], 
//                                     +b['2022 Population']);
